Module goohttp::http_server

source ·
Available on crate feature esp only.
This module provides an HttpServer that is compatible with embedded systems like the ESP32, but also supports many of the popular HttpServer features.

Structs

  • When developing for embedded systems, you cannot, as of now, use asynchronous TcpListeners and thus one of the most popular HttpServers. But this does not immediately mean that you have to miss out on all of the features provided by axum. The solution is to do everything with a synchronous TcpListener.